#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2023-05-20

# based on https://github.com/allangood/check_mk/tree/master/plugins/squid
#
# rewritten for cmk 2.x
#
# 2023-05-20: moved to ~/local/lib/check_mk/gui/plugins/wato
#             renamed from check_squid.py to squid.py
#             changed client_reqps to client_requests
#             changed server_reqps to server_requests
#             changed cpu_time to cpu_usage
# 2023-12-02: add ip_address option for agent plugin
#             add available_number_of_file_descriptors for check section

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    Tuple,
    TextInput,
    Float,
)
from cmk.gui.plugins.wato.utils import (
    rulespec_registry,
    HostRulespec,
    RulespecGroupCheckParametersApplications,
    CheckParameterRulespecWithItem,
    Levels,
)

from cmk.gui.cee.plugins.wato.agent_bakery.rulespecs.utils import (
    RulespecGroupMonitoringAgentsAgentPlugins,
)


def _valuespec_squid():
    return Dictionary(
        title=_('Squid Web Proxy (Linux)'),
        elements=[
            ('client_requests',
             Levels(
                 title=_('Set levels for Client Requests'),
                 unit='/s',
             )),
            ('client_hits',
             Levels(
                 title=_('Set levels for Client Hits'),
                 unit='/s'
             )),
            ('server_requests',
             Levels(
                 title=_('Set levels for Server Requests'),
                 unit='/s',
             )),
            ('cpu_usage',
             Levels(
                 title=_('Set levels for Squid CPU usage'),
                 unit='%',
                 default_levels=(60.0, 80.0)
             )),
            ('dns_time',
             Tuple(
                 title=_('Set levels for DNS response time'),
                 elements=[
                     Float(title=_('Warning at'), default_value=2.0, unit='seconds'),
                     Float(title=_('Critical at'), default_value=4.0, unit='seconds'),
                 ])),
            ('available_number_of_file_descriptors',
             Levels(
                 title=_('Set levels for Squid available file descriptors'),
                 unit='number of',
                 # default_levels=(60.0, 80.0)
             )),
        ]
    )


rulespec_registry.register(
    CheckParameterRulespecWithItem(
        check_group_name='squid',
        group=RulespecGroupCheckParametersApplications,
        match_type='dict',
        parameter_valuespec=_valuespec_squid,
        title=lambda: _('Squid Web Proxy'),
        item_spec=lambda: TextInput(
            title="Squid counter",
            help='Service name without "Squid" i.e. "DNS response time"',
        ),
    ))


def _valuespec_agent_squid():
    return Dictionary(
        help=_('The plugin <tt>squid</tt> allows monitoring of Squid Web Proxies.'),
        title=_('Squid Web Proxy (Linux)'),
        elements=[
            ('ip_address',
             TextInput(
                 title=_('IP Address/Hostname'),
                 help=_('The IP-Address/Hostname squidclient connects to.'),
                 default_value='localhost',
             )),
            ('port',
             Integer(
                 title=_('Port number'),
                 help=_('TCP port number that squidclient connects to.'),
                 default_value=3128,
             )),
        ]
    )


rulespec_registry.register(
    HostRulespec(
        group=RulespecGroupMonitoringAgentsAgentPlugins,
        name='agent_config:squid',
        valuespec=_valuespec_agent_squid,
    )
)
